@@ -1,10 +1,8 @@
-/* SPDX-License-Identifier: LGPL-2.1-or-later */
+// SPDX-License-Identifier: LGPL-2.1-or-later
 #ifndef __ALSA_HINAWA_ENUM_TYPES_H__
 #define __ALSA_HINAWA_ENUM_TYPES_H__
 
-#include <glib-object.h>
-#include <linux/firewire-constants.h>
-#include <sound/firewire.h>
+G_BEGIN_DECLS
 
 /**
  * HinawaFwTcode:
@@ -84,6 +82,37 @@ typedef enum {
 	HINAWA_FW_RCODE_INVALID,
 } HinawaFwRcode;
 
+/**
+ * HinawaFwReqError:
+ * @HINAWA_FW_REQ_ERROR_CONFLICT_ERROR:	For error of conflicting.
+ * @HINAWA_FW_REQ_ERROR_DATA_ERROR:	For error of data.
+ * @HINAWA_FW_REQ_ERROR_TYPE_ERROR:	For error of type.
+ * @HINAWA_FW_REQ_ERROR_ADDRESS_ERROR:	For error of address.
+ * @HINAWA_FW_REQ_ERROR_SEND_ERROR:	For error of sending.
+ * @HINAWA_FW_REQ_ERROR_CANCELLED:	For cancellation.
+ * @HINAWA_FW_REQ_ERROR_BUSY:		For busyness.
+ * @HINAWA_FW_REQ_ERROR_GENERATION:	For generation.
+ * @HINAWA_FW_REQ_ERROR_NO_ACK:		For no acknowledge.
+ * @HINAWA_FW_REQ_ERROR_INVALID:	For rcode out of specification.
+ *
+ * A set of error code for [class@Hinawa.FwReq]. Each of them has the same value as the
+ * corresponding enumeration in [enum@Hinawa.FwRcode].
+ *
+ * Since: 2.5.
+ */
+typedef enum {
+	HINAWA_FW_REQ_ERROR_CONFLICT_ERROR	= HINAWA_FW_RCODE_CONFLICT_ERROR,
+	HINAWA_FW_REQ_ERROR_DATA_ERROR		= HINAWA_FW_RCODE_DATA_ERROR,
+	HINAWA_FW_REQ_ERROR_TYPE_ERROR		= HINAWA_FW_RCODE_TYPE_ERROR,
+	HINAWA_FW_REQ_ERROR_ADDRESS_ERROR	= HINAWA_FW_RCODE_ADDRESS_ERROR,
+	HINAWA_FW_REQ_ERROR_SEND_ERROR		= HINAWA_FW_RCODE_SEND_ERROR,
+	HINAWA_FW_REQ_ERROR_CANCELLED		= HINAWA_FW_RCODE_CANCELLED,
+	HINAWA_FW_REQ_ERROR_BUSY		= HINAWA_FW_RCODE_BUSY,
+	HINAWA_FW_REQ_ERROR_GENERATION		= HINAWA_FW_RCODE_GENERATION,
+	HINAWA_FW_REQ_ERROR_NO_ACK		= HINAWA_FW_RCODE_NO_ACK,
+	HINAWA_FW_REQ_ERROR_INVALID		= HINAWA_FW_RCODE_INVALID,
+} HinawaFwReqError;
+
 /**
  * HinawaSndUnitType:
  * @HINAWA_SND_UNIT_TYPE_DICE:		The type of DICE ASIC.
@@ -98,6 +127,7 @@ typedef enum {
  * A representation of type for sound unit defined by Linux sound subsystem.
  *
  * Since: 1.0
+ * Deprecated: 2.5. Use [enum@Hitaki.AlsaFirewireType] in libhitaki library instead.
  */
 typedef enum {
 	HINAWA_SND_UNIT_TYPE_DICE = 1,
@@ -119,7 +149,7 @@ typedef enum {
  *					firewire character device.
  * @HINAWA_FW_NODE_ERROR_FAILED:	The system call fails.
  *
- * A set of error code for GError with domain which equals to #hinawa_fw_node_error_quark().
+ * A set of error code for [struct@GLib.Error] with domain which equals to Hinawa.FwNodeError.
  *
  * Since: 2.1
  */
@@ -136,7 +166,7 @@ typedef enum {
  * @HINAWA_FW_RESP_ERROR_RESERVED:		The instance is already associated to reserved address range.
  * @HINAWA_FW_RESP_ERROR_ADDR_SPACE_USED:	The address space is used exclusively.
  *
- * A set of error code for GError with domain which equals to #hinawa_fw_resp_error_quark().
+ * A set of error code for [struct@GLib.Error] with domain which equals to Hinawa.FwRespError.
  *
  * Since: 2.2
  */
@@ -151,7 +181,7 @@ typedef enum {
  * @HINAWA_FW_FCP_ERROR_TIMEOUT:	The transaction is canceled due to response timeout.
  * @HINAWA_FW_FCP_ERROR_LARGE_RESP:	The size of response is larger than expected.
  *
- * A set of error code for GError with domain which equals to #hinawa_fw_fcp_error_quark().
+ * A set of error code for [struct@GLib.Error] with domain which equals to Hinawa.FwFcpError.
  *
  * Since: 2.1
  */
@@ -173,9 +203,10 @@ typedef enum {
  * @HINAWA_SND_UNIT_ERROR_WRONG_CLASS:	The hwdep device is not for the unit expected by the class.
  * @HINAWA_SND_UNIT_ERROR_FAILED:	The system call fails.
  *
- * A set of error code for GError with domain which equals to #hinawa_snd_unit_error_quark().
+ * A set of error code for [struct@GLib.Error] with domain which equals to Hinawa.SndUnitError.
  *
  * Since: 2.1
+ * Deprecated: 2.5. Use Hitaki.AlsaFirewireError in libhitaki library instead.
  */
 typedef enum {
 	HINAWA_SND_UNIT_ERROR_DISCONNECTED,
@@ -192,9 +223,10 @@ typedef enum {
  * HinawaSndDiceError:
  * @HINAWA_SND_DICE_ERROR_TIMEOUT:	The transaction is canceled due to response timeout.
  *
- * A set of error code for GError with domain which equals to #hinawa_snd_dice_error_quark().
+ * A set of error code for [structGLib.Error] with domain which equals to Hinawa.SndDiceError.
  *
  * Since: 2.1
+ * Deprecated: 2.5. Use Hitaki.AlsaFirewireError in libhitaki library instead.
  */
 typedef enum {
 	HINAWA_SND_DICE_ERROR_TIMEOUT,
@@ -223,6 +255,7 @@ typedef enum {
  * A set of status code for Echo Audio Fireworks Transaction.
  *
  * Since: 2.1
+ * Deprecated: 2.5. Use Hitaki.EfwProtocolError in libhitaki library instead.
  */
 typedef enum {
 	HINAWA_SND_EFW_STATUS_OK		= 0,
@@ -244,4 +277,6 @@ typedef enum {
 	HINAWA_SND_EFW_STATUS_LARGE_RESP,
 } HinawaSndEfwStatus;
 
+G_END_DECLS
+
 #endif
